@@ -28,8 +28,7 @@ from hildon import Program, StackableWindow, PannableArea, Button, AppMenu, GtkB
 from hildon import hildon_banner_show_information, hildon_gtk_window_set_progress_indicator, TouchSelector
 from hildon import  BUTTON_ARRANGEMENT_VERTICAL, BUTTON_ARRANGEMENT_HORIZONTAL, TOUCH_SELECTOR_SELECTION_MODE_MULTIPLE
 
-# set timeout to 15 seconds
-timeout = 15
+timeout = 8
 socket.setdefaulttimeout(timeout)
 
 pluginHnd = PluginLoader(config=False,format="raw")
@@ -801,6 +800,27 @@ class BaasGui(object):
         self.state.history[self.input_command] =  self.state.history[self.input_command][0:self.state.history_len]
         self.state.save()
 
+    def do_request(self, func, term):
+        for i in range(0,2):
+            try:
+               result = func(term)
+               return result
+            except URLError, e:
+                if i < 1:
+                    print "urllib2 timeout, retrying"
+                    pass
+                else:
+                    raise(e)
+            except socket.timeout, e:
+                if i < 1:
+                    print "socket timeout, retrying"
+                    pass
+                else:
+                    raise(e)
+            except Exception, e:
+                raise(e)
+        return []
+
     def ask_buddy(self):
 
         self.waiting_start('msg')
@@ -829,9 +849,9 @@ class BaasGui(object):
             if self.input_page > 1:
                 term = '%s [%d]' % (self.term, self.input_page)
    
-            result_msg = ''
+            result_msg = []
             try:
-                result_msg = commando_func(term)
+                result_msg = self.do_request(commando_func, term)
             except URLError, e:
                 hildon_banner_show_information(self.window, "",
                     "Request failed, timed out.")
@@ -986,25 +1006,6 @@ class BaasGui(object):
             self.detail_dialog.action_area.pack_start(parea, True, True, 0)
             self.detail_dialog.show_all()
 
-        parea = PannableArea()
-        treeview = GtkTreeView(HILDON_UI_MODE_NORMAL)
-        lstore = ListStore(str, str);
-        history = self.state.history.get(self.input_command,[])
-        for e in history:
-            (term, lang) = self.parse_term(e)
-            sel_text = term
-            if lang and self.input_command != 'deli':
-                sel_text += " <small>/ %s</small>" % self.lang.get(self.input_command, short=lang)[1]
-            elif lang:
-                sel_text += " <small>/ most popular</small>"
-            lstore.append([str(e),sel_text])
-        treeview.set_model(lstore)
-        renderer = CellRendererText()
-        column = TreeViewColumn('title', renderer, markup=1)
-        column.set_property("expand", True)
-        treeview.append_column(column)
-        treeview.connect("row-activated", self.history_picked)
-
     def build_next_results_markup(self, text):
         return '<span font_stretch="expanded" style="italic" color="grey">%s</span>' % text
 
